@@ -95,7 +95,7 @@ import re
 
 import pytest
 
-from .oot_step import step, TestStepFail
+from .oot_step import step, TestStepFail, TestRunTimeError
 
 
 def pytest_collect_file(parent, path):
@@ -116,13 +116,13 @@ class TestCaseFile(pytest.File):
             import importlib
             self.objs = importlib.import_module(self.test_bed)
 
+        current_line_number = 0
+        case_number = 0
         for case in self.cases:
-            line1_end = case.find('\n')
-            line1 = case[0:line1_end].strip()
-            steps = case[line1_end:]
-            m = re.match(r'(\w+)\s*\((.*)\)', line1)
-            (case_id, case_dec) = m.group(1,2)
-            yield TestCaseItem(case_id, self, case_dec, steps)
+            case_id = case[0:case.find(' ')]
+            current_line_number += self.case_lines[case_number]
+            case_number += 1
+            yield TestCaseItem(case_id, self, case, current_line_number)
 
     def __parse_suite(self, suite_content):
         ''' To parse the system case file, see detail of the system test file example
@@ -132,14 +132,15 @@ class TestCaseFile(pytest.File):
 
         # split cases, notice that the first element of the cases is about the test suite description
         cases = suite_content.split("\ncase_")
+        self.case_lines = [c.count('\n')+1 for c in cases]
 
         # Deal with the test suite description; cases[0] is about the test suite summary
         self.name = 'unknown'
         self.test_bed = None
         self.suite_attr = {}
         self.cases = cases[1:]
-        lines = cases[0].split("\n")
-        for line in lines:
+        header = cases[0].split("\n")
+        for line in header:
             line = line.strip()
             if len(line) == 0: continue
             if line[0] == '#': continue
@@ -157,31 +158,53 @@ class TestCaseFile(pytest.File):
 class TestCaseItem(pytest.Item):
     ''' A case structure, one case can contain multiple steps
     '''
-    def __init__(self, name, parent, dec, steps):
-        super(TestCaseItem, self).__init__(name, parent)
-        self.dec = dec
-        self.steps = steps
+    # def __init__(self, name, parent, case_dec, steps):
+    #     super(TestCaseItem, self).__init__(name, parent)
+    #     self.case_dec = case_dec
+    #     self.steps = steps
+
+    def __init__(self, case_id, parent, case_string, line_number):
+        super(TestCaseItem, self).__init__(case_id, parent)
+        header_end = case_string.find('\n')
+        self.case_header = case_string[0:header_end].strip()
+        self.steps = case_string[header_end:].split('\n')
+        self.first_line = line_number
+        self.parent = parent
+        #m = re.match(r'(\w+)\s*\((.*)\)', line1)
+        #(case_id, case_dec) = m.group(1,2)
 
     def runtest(self):
-        steps_l = self.steps.split('\n')
-        for step_string in steps_l:
-            step_string = step_string.strip()
+        self.current_step = 0
+        for step_string in self.steps:
+            #step_string = step_string.strip()
             #if len(step_string) == 0: continue
             #if step_string[0] == '#': continue
             #step_obj = TestStep(step, self) # To create a step_obj with parsing
             #step_obj.execute()
             step(step_string, self.parent.objs, self)
             #if step == '': raise TestException(self, self.name, step)
+            self.current_step += 1
 
     def repr_failure(self, excinfo):
         """ called when self.runtest() raises an exception. """
+
+        failed_line_number = self.first_line + self.current_step + 1
+
+        fail_string = "case_" + self.case_header + "\n".join(self.steps[0:self.current_step])
+        fail_string += '\n>' + self.steps[self.current_step][1:]
+        fail_string += "\nE" + excinfo.value.args[1][1:]
+
+        fail_string += "\n\n%s:" % self.parent.fspath + "%d" % failed_line_number
+
         if isinstance(excinfo.value, TestStepFail):
-            return "\n".join([
-            "usecase execution failed",
-            " failed step: %r: %r" % excinfo.value.args[1:3]
-            ])
+            fail_string += ": TestStepFail"
+
+        elif isinstance(excinfo.value, TestRunTimeError):
+            fail_string += ": TestRunTimeError"
+
+        return fail_string
 
     def reportinfo(self):
         ''' Called when there is a failure as a failed case title'''
-        return self.fspath, 0, "case_%s (%s)" % (self.name, self.dec)
+        return self.fspath, 0, "%s" % self.case_header
 
